@@ -13,6 +13,7 @@ from ezcharts.components.fastcat import SeqSummary
 from ezcharts.components.nextclade import NextClade, NXTComponent
 from ezcharts.components.reports.labs import LabsReport
 from ezcharts.components.theme import LAB_head_resources
+from ezcharts.layout.snippets import DataTable
 from ezcharts.layout.snippets import Grid
 from ezcharts.layout.snippets import OffCanvas
 from ezcharts.layout.snippets import Progress
@@ -54,8 +55,15 @@ def main(args):
         elif style == "scatter":
             plot = ezc.scatterplot(data=df, x='year', y='sales', hue='product')
         elif style == 'histogram':
-            plot = ezc.histplot(
-                data=np.random.randint(0, 11, size=1000), bins=10)
+            hist_data = pd.DataFrame(
+                        [np.random.normal(loc=10.0, size=1000),
+                         np.random.normal(loc=12.0, size=1000),
+                         np.random.normal(loc=14.0, size=1000)]).T
+            hist_data.columns = ['sample1', 'sample2', 'sample3']
+            plot = ezc.histplot(hist_data, bins=50, stat='proportion')
+
+            plot.xAxis.name = 'Read length'
+            plot.yAxis.name = 'Number of reads'
         elif style == "bar":
             plot = ezc.barplot(data=df, x='year', y='sales', hue='product')
         else:
@@ -136,7 +144,7 @@ def main(args):
     with report.add_section('Alignment results', 'Results'):
         # This is the tabbed section with ezcharts!
         tabs = Tabs()
-        with tabs.add_tab('Summary', True):
+        with tabs.add_tab('Summary'):
             # Grids are snippets that provide responsive
             # layouts via css grid
             with Grid():
@@ -144,16 +152,19 @@ def main(args):
                 EZChart(example_plot("scatter"), 'epi2melabs')
                 EZChart(example_plot("bar"), 'epi2melabs')
                 EZChart(example_plot("histogram"), 'epi2melabs')
-        with tabs.add_tab('Accuracy', False):
+        with tabs.add_tab('Accuracy'):
             p("This is a mixed tab!")
             EZChart(example_plot(), 'epi2melabs')
-        with tabs.add_tab('Depth', False):
+        with tabs.add_tab('Depth'):
             p('Testing, testing, 1 2 3')
 
         # Dropdowns are nested one more level
-        with tabs.add_dropdown_menu('Example'):
-            with tabs.add_dropdown_tab('First', False):
+        with tabs.add_dropdown_menu('Example', change_header=False):
+            with tabs.add_dropdown_tab('First'):
                 EZChart(example_plot(), 'epi2melabs')
+            with tabs.add_dropdown_tab('Second'):
+                p("This is the second dropdown item.")
+                EZChart(example_plot('bar'), 'epi2melabs')
 
     with report.add_section('Nextclade results', 'Nextclade', True):
         NextClade(nxt_json)
@@ -163,6 +174,14 @@ def main(args):
             ideogram(blocks='cytobands'),
             'epi2melabs', height="800px")
 
+    with report.add_section('Table', 'Table'):
+        df = pd.DataFrame(np.random.random((4, 4))) * 10
+        df.columns = pd.MultiIndex.from_product(
+            [['sample1', 'sample2'], ['mapped', 'unmapped']])
+        df['chr'] = [1, 2, 3, 4]
+        df = df.set_index('chr', drop=True)
+        DataTable.from_pandas(df, use_index=True)
+
     logger.info('Reticulating splines')
     report.write(args.output)
 
